rerun

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

README

🪃 Rerun

Testo plugin for rerunning failed tests.

Similar --last-failed flag from Pytest

Quick Start

go get github.com/ozontech/testo-toppings

Add it to your T:

package main

import (
	"github.com/ozontech/testo"
	"github.com/ozontech/testo-toppings/rerun"
)

type T struct {
	*testo.T
	*rerun.PluginRerun
}

Run tests as usual:

go test .

To rerun only failed tests run tests again with flag -rerun.failed:

go test . -rerun.failed

This flag will instruct plugin to execute tests failed in the previous run.

If there are no previous runs or no failed tests since last run, suite will be skipped by calling t.Skip() underneath.

Documentation

Overview

Package rerun provides plugin for pytest-like rerun functionality for failed tests.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PluginRerun

type PluginRerun struct {
	*testo.T
}

PluginRerun providers plugin for pytest-like rerun functionality for failed tests.

func (*PluginRerun) Plugin

Plugin implements testoplugin.Plugin.

Jump to