Documentation
¶
Overview ¶
Package parallel provides plugin to mark tests as parallel by default.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WithSync ¶
func WithSync() testoplugin.Option
WithSync signals that this test is to be run in sync with (and only with) other sync tests.
Types ¶
type PluginParallel ¶
PluginParallel marks all tests as parallel by default.
func (*PluginParallel) Plugin ¶
func (p *PluginParallel) Plugin(_ testoplugin.Plugin, options ...testoplugin.Option) testoplugin.Spec
Plugin implements testoplugin.Plugin.
Click to show internal directories.
Click to hide internal directories.